#include "src/createeventdialog.h"
#include "ui_createeventdialog.h"
#include <QResource>
#include <QStandardItem>

CreateEventDialog::CreateEventDialog(MEvent* aEvent,
                                     QWidget *parent) :
    QDialog(parent),
    ui(new Ui::CreateEventDialog)
{
    mEvent = aEvent;
    ui->setupUi(this);
    showMaximized();
    ui->eventTypeLabel->setText(mEvent->eventType().data().toString());

    //Back button
    connect(ui->backButton, SIGNAL(clicked()),
            this, SLOT(reject()) );
    QResource::registerResource("appdata/pictures.qrc");
    QIcon* icon = new QIcon();
    icon->addFile(":appdata/back.jpg");
    ui->backButton->setIcon(*icon);


    //Accept button
    connect(ui->acceptButton, SIGNAL(clicked()),
            this, SLOT(saveTimes( ) ) );
    QIcon* icon2 = new QIcon();
    icon2->addFile(":appdata/accept.jpg");
    ui->acceptButton->setIcon(*icon2);

    ui->endTimeSlider->setValue(12);
    ui->startTimeSlider->setValue(12);

    //Start Time slider & time edit
    connect(ui->startTimeEdit, SIGNAL(timeChanged(QTime)), this, SLOT(fromTimeToIntStart(QTime) ) );
    connect(ui->startTimeSlider, SIGNAL(valueChanged(int)), this, SLOT(fromIntToTimeStart(int) ) );

    //End Time slider & time edit
    connect(ui->endTimeEdit, SIGNAL(timeChanged(QTime)), this, SLOT(fromTimeToIntEnd(QTime) ) );
    connect(ui->endTimeSlider, SIGNAL(valueChanged(int)), this, SLOT(fromIntToTimeEnd(int) ) );

    printDate();
}

CreateEventDialog::~CreateEventDialog()
{
    delete ui;
}

void CreateEventDialog::setModelIndex(QModelIndex &aModel)
{
    mModelIndex = aModel;
    QVariant data = mModelIndex.data();
    QString str = data.toString();
    ui->eventTypeLabel->setText(str);

}

void CreateEventDialog::fromTimeToIntStart(QTime aTime)
{

    setSlider(ui->startTimeSlider, aTime );

}


void CreateEventDialog::fromTimeToIntEnd(QTime aTime)
{
    setSlider(ui->endTimeSlider, aTime );
}


void CreateEventDialog::setSlider(QSlider *aSlider, QTime aValue)
{
    int hour = aValue.hour();
    aSlider->setValue( hour );
}


void CreateEventDialog::fromIntToTimeStart(int aHour)
{
    setTime(ui->startTimeEdit, aHour );
}


void CreateEventDialog::fromIntToTimeEnd(int aHour)
{
    setTime(ui->endTimeEdit, aHour );;
}

void CreateEventDialog::setTime(QTimeEdit *aTimeEdit, int aValue)
{
    QTime time;
    time.setHMS(aValue, 0, 0);
    aTimeEdit->setTime(time);
}


void CreateEventDialog::saveTimes( )
{
    mEvent->setStartTime(ui->startTimeSlider->value() );
    mEvent->setEndTime(ui->endTimeSlider->value() );
    this->accept();
}

void CreateEventDialog::printDate()
{
    QDate date = mEvent->date();
    int year;
    int month;
    int day;
    date.getDate(&year, &month, &day);
    QString dateText;
    dateText.append(QString::number(day)+
                    "."+QString::number(month)+
                    "."+QString::number(year));
    ui->dateLabel->setText(dateText);
}
