#include "mainwindow.h"
#include "adddialog.h"
#include "viewdialog.h"
#include "ui_mainwindow.h"
#include <QIcon>
#include <QPixmap>
#include <QResource>
#include <QPushButton>
#include <QSize>
#include <QDate>
#include <QDateTime>
#include <QLabel>
#include <QFont>



#include "event.h"

MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow)
{
    ui->setupUi(this);
    //Quit handler
    connect(ui->exitButton, SIGNAL(clicked()),
            this, SLOT(close()  ) );

    //Add handler
    connect(ui->addButton, SIGNAL(clicked()),
            this, SLOT(addButtonClicked() ) );
    //View handler
    connect(ui->viewButton, SIGNAL(clicked()),
            this,SLOT(viewButtonClicked() ) );

    mEventModel = new EventModel(NULL);
    QResource::registerResource("appdata/pictures.qrc");
    QIcon* heavyIcon = new QIcon();
    heavyIcon->addFile(":appdata/crane.jpg");
    //ui->backButton->setIcon(*icon);
    QIcon* pouringIcon = new QIcon();
    pouringIcon->addFile(":appdata/pouring.jpg");

    mEventModel->addEvent(*heavyIcon,QString("Heavy lifting"));
    mEventModel->addEvent(*pouringIcon, QString("Concrete pouring"));

    QIcon* icon = new QIcon();
    icon->addFile(":appdata/add2.bmp");
    ui->addButton->setIcon(*icon);


    //add view image
    //QResource::registerResource("appdata/pictures.qrc");
    QIcon* icon_view = new QIcon();
    icon_view->addFile(":appdata/view.bmp");
    ui->viewButton->setIcon(*icon_view);
    //add exit button image
    QIcon* icon_quit = new QIcon();
    icon_quit->addFile(":appdata/quit.bmp");
    ui->exitButton->setIcon(*icon_quit);

    //Make Today text big
    QFont todayFont("Arial", 16, 2);
    ui->todayLabel->setFont(todayFont);


}

MainWindow::~MainWindow()
{
    delete ui;
}

void MainWindow::addButtonClicked()
{
    MEvent* event = new Event();
    AddDialog* diag = new AddDialog(mEventModel, event, this);

    int rv = diag->exec();
    if(rv == QDialog::Accepted)
    {
        //Add event to list
        mEventStorage.addEvent(event);
        updateTodayPanel();
    }
    else
    {
        delete event;
    }
    diag->deleteLater();
}

void MainWindow::viewButtonClicked()
{
    ViewDialog* diag = new ViewDialog(&mEventStorage, this);
    diag->exec();
    diag->deleteLater();
}

void MainWindow::updateTodayPanel()
{
    QDateTime today = QDateTime::currentDateTime();

    QDate todayDate = today.date();
    QList<MEvent*> todayList = mEventStorage.dayEvents(todayDate);
    //Return if there are no events for today
    if(todayList.size() == 0)
        return;

    //Show some events for today
    for(int i = 0; i < todayList.size(); i++)
    {
        MEvent* oneEvent = todayList.at(i);
        int startTime = oneEvent->startTime();
        int endTime = oneEvent->endTime();
        int hours = today.time().hour();
        if(hours > endTime)
            continue;
        else
        {
            QLabel* label = new QLabel(this);
            if(!ui->todayPanelLayout->itemAtPosition(i,0))
            {
                label->setText(oneEvent->eventType().data().toString());
                ui->todayPanelLayout->addWidget(label,i,0);
                label->show();
                label = new QLabel(this);
                QString timeStr("Time: ");
                timeStr.append(QString::number(startTime));
                timeStr.append(" - ");
                timeStr.append(QString::number(endTime));
                label->setText(timeStr);
                ui->todayPanelLayout->addWidget(label, i, 1);
            }//if
        }//if
    }//else

}//updateTodayPanel
