#include "src/viewdialog.h"
#include "ui_viewdialog.h"
#include <QIcon>
#include <QPixmap>
#include <QResource>
#include <QPushButton>
#include <QSize>
#include <QBrush>
#include <QTextCharFormat>
#include "eventstorage.h"
#include "showinfodialog.h"

ViewDialog::ViewDialog(EventStorage* aEventStorage, QWidget *parent) :
    QDialog(parent),
    ui(new Ui::ViewDialog)
{
    mEventStorage=aEventStorage;
    ui->setupUi(this);
    //handler to the back button
    connect(ui->backButton, SIGNAL(clicked()),
            this, SLOT(reject() ) );
    //adding resources
    QResource::registerResource("appdata/pictures.qrc");
    //Icon for back btn
    QIcon* icon = new QIcon();
    icon->addFile(":appdata/back.jpg");
    ui->backButton->setIcon(*icon);
    //Filling calendar with contents of the EventStorage
    fillCalendar(aEventStorage);
    //Handler to the calendar clicks:
   connect(ui->calendarWidget, SIGNAL(clicked(QDate)),
            this, SLOT(viewDay(QDate) ) );
}

ViewDialog::~ViewDialog()
{
    delete ui;
}

void ViewDialog::fillCalendar(EventStorage* aEventStorage){
    int size=aEventStorage->size();

    //Getting size of the EventStorage
    //And adding event to the right date
    for(int i=0; i<size; i++){
        MEvent* event = aEventStorage->eventAt(i);
        //creating date
        QDate date = event->date();
        //Brush to set color for day:
        QBrush brush;
        brush.setColor(Qt::green);
        QTextCharFormat cf = ui->calendarWidget->dateTextFormat( date );
        //Setting background colour to green.
        cf.setBackground( brush );
        ui->calendarWidget->setDateTextFormat( date, cf );

    }
}
void ViewDialog::viewDay(QDate date){
    //checking that there is events
    if(mEventStorage->size()!=0){
        //checking that clicked day has event; else do nothing
        if(mEventStorage->dateHasEvent(date)==true){
            //showing right dialog for date:
            ShowInfoDialog* diag = new ShowInfoDialog(mEventStorage->dayEvents(date), this);
            diag->exec();
            diag->deleteLater();
        }
    }
}

